/*
 * Copyright (c) 1999 Venkat. All Rights Reserved.
 *
 * The author (Venkat) grants everyone a non-exclusive, royalty free, 
 * license to use, modify and redistribute this software in source and 
 * binary code form, provided that: 
 * i) this copyright notice appear on all copies of the software; and 
 * ii) the software is not utilized in a manner which is disparaging 
 * to the author.
 */

package com.venkat.RMIDemo;

import java.applet.*;
import java.awt.*;
import java.rmi.*;
import java.rmi.server.*;
import java.io.*;
import java.net.*;


public
class
	BBScoreBoard
extends
	Applet
implements
	ScoreReceiver
{
	private ScoreCanvas bullsScore;
	private ScoreCanvas jazzScore;
	private Font theFont1 = new Font("TimesRoman",Font.BOLD,45);
	private Panel bullsPanel;
	private Panel jazzPanel;
	private Label bullsLabel;
	private Label jazzLabel;
	private ScoreSender theRemoteServer = null;

	public
	void
		init()
	{
		bullsPanel = new Panel();
		jazzPanel = new Panel();
		bullsLabel = new Label("BULLS",Label.CENTER);
		jazzLabel = new Label("JAZZ",Label.CENTER);
		bullsPanel.setLayout( new GridLayout(2,1,5,5) );
		jazzPanel.setLayout( new GridLayout(2,1,5,5) );
		bullsScore = new ScoreCanvas();
		jazzScore = new ScoreCanvas();
		setSize(300,400);
		setBackground(Color.gray);
		bullsPanel.add(bullsLabel);
		jazzPanel.add(jazzLabel);
		bullsPanel.add(bullsScore);
		jazzPanel.add(jazzScore);
		add(bullsPanel);
		add(jazzPanel);
		validate();
		setVisible(true);

		try 
		{
			// export the applet as a remote object
			System.out.println("exporting ClientApplet as remote object");
			UnicastRemoteObject.exportObject(this);
	    
			// locate Remote Server in the hostmachine registry
			URL base = getDocumentBase();
			String remoteServerName = "//" + base.getHost() + ":" +
			getParameter("registryPort") + "/com.venkat.RMIDemo.BBServer";
			theRemoteServer = (ScoreSender)Naming.lookup(remoteServerName);
			theRemoteServer.register(this);
		} 
		catch (Exception e)
		{
			System.out.println(e.getMessage());
			e.printStackTrace();
		}
	} // end init method

	public
	void
		paint( Graphics g )
	{
		g.setFont( theFont1 );
		setBackground(Color.gray);
		//bullsScore.repaint();
		//knicksScore.repaint();
	} // end paint method


	public
	void
		update( GameEvent anEvent )
	{
		ShotAttempt anAttempt = (ShotAttempt) anEvent;
		int aPoint = anAttempt.getPointScored();
		String aTeam = anAttempt.getTeamName();
		if ( aTeam.equals("Bulls") )
		{
			bullsScore.update( aPoint );
		}
		else
		{
			jazzScore.update( aPoint );
		}
		
	} // end update method


	public
	void
		bringUpToDate( int aWinningTotal, int aLosingTotal )
	{
		bullsScore.update( aWinningTotal );
		jazzScore.update( aLosingTotal );
	} // end bringUpToDate method


	public
	void
		destroy() 
    {
		if (theRemoteServer != null)
		{
			try
			{	
				theRemoteServer.cancel(this);
			} 
			catch (Exception e)
			{
				e.printStackTrace();
			}
		}
    } // end destroy method

} // end TestScoreBoard Applet class